netapp_ontap.models.analytics_info API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.analytics_info`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AnalyticsInfoSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AnalyticsInfo object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `by_accessed_time GET POST PATCH`

    The by_accessed_time field of the analytics_info.

  `by_modified_time GET POST PATCH`

    The by_modified_time field of the analytics_info.

  `bytes_used GET POST PATCH`

    Number of bytes used on-disk

    Example: 15436648448

  `file_count GET POST PATCH`

    Number of descendants

    Example: 21134

  `subdir_count GET POST PATCH`

    Number of sub directories

    Example: 35